@@ -1,7 +1,7 @@
 /* glpsol.c */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
@@ -23,6 +23,7 @@
 -- 02111-1307, USA.
 ----------------------------------------------------------------------*/
 
+#include <limits.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -36,7 +37,7 @@
 /* on the simplex method is used.                                     */
 /*--------------------------------------------------------------------*/
 
-static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 4.7";
+static char *version = "GLPSOL -- GLPK LP/MIP Solver, Version 4.8";
 /* version string */
 
 static int format = 0;
@@ -96,6 +97,9 @@ static char *out_bnds = NULL;
 static int tmlim = -1;
 /* solution time limit, in seconds */
 
+static int memlim = -1;
+/* available memory limit, in megabytes */
+
 static int check = 0;
 /* if this flag is set, only input data checking is required */
 
@@ -213,6 +217,8 @@ static void display_help(char *my_name)
          "in plain ");
       print("                     text format (LP only)");
       print("   --tmlim nnn       limit solution time to nnn seconds");
+      print("   --memlim nnn      limit available memory to nnn megabyt"
+         "es");
       print("   --check           do not solve problem, check input dat"
          "a only");
       print("   --name probname   change problem name to probname");
@@ -401,6 +407,17 @@ static void parse_cmdline(int argc, char *argv[])
                exit(EXIT_FAILURE);
             }
          }
+         else if (p("--memlim"))
+         {  k++;
+            if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
+            {  print("No memory limit specified");
+               exit(EXIT_FAILURE);
+            }
+            if (str2int(argv[k], &memlim) || memlim < 0)
+            {  print("Invalid memory limit `%s'", argv[k]);
+               exit(EXIT_FAILURE);
+            }
+         }
          else if (p("--check"))
             check = 1;
          else if (p("--name"))
@@ -571,6 +588,9 @@ int main(int argc, char *argv[])
       double start;
       /* parse command line parameters */
       parse_cmdline(argc, argv);
+      /* set available memory limit */
+      if (memlim >= 0 && memlim < INT_MAX / (1024 * 1024))
+         lib_env_ptr()->mem_limit = (1024 * 1024) * memlim;
       /* remove all output files specified in the command line */
       if (display != NULL) remove(display);
       if (out_bas != NULL) remove(out_bas);
