@@ -1,7 +1,7 @@
 /* tspsol.c */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
@@ -453,14 +453,14 @@ static double max_flow(int nn, int ne, int beg[], int end[],
       /* check number of non-zero entries */
       insist(nz == 2 * (ne + 1));
       /* load the constraint matrix into the LP problem object */
-      lpx_load_mat3(lp, nz, rn, cn, aa);
+      lpx_load_matrix(lp, nz, rn, cn, aa);
       ufree(rn);
       ufree(cn);
       ufree(aa);
       /* the objective function is the total flow through the network,
          which should be maximized */
       lpx_set_obj_dir(lp, LPX_MAX);
-      lpx_set_col_coef(lp, ne + 1, 1.0);
+      lpx_set_obj_coef(lp, ne + 1, 1.0);
       /* solve the LP problem */
       lpx_set_int_parm(lp, LPX_K_MSGLEV, 2);
       lpx_set_real_parm(lp, LPX_K_OUTDLY, 5.0);
