@@ -1,7 +1,7 @@
 /* glplpx8c.c */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
@@ -822,8 +822,10 @@ LPX *lpx_read_cpxlp(char *fname)
       }
       dsa->lp = lpx_create_prob();
       lpx_create_index(dsa->lp);
+#if 0
       /* read very first character */
       read_char(dsa);
+#endif
       /* scan very first token */
       scan_token(dsa);
       /* parse definition of the objective function */
@@ -1039,7 +1041,7 @@ int lpx_write_cpxlp(LPX *lp, char *fname)
             }
          }
          else if (i == 1)
-         {  temp = lpx_get_obj_c0(lp);
+         {  temp = lpx_get_obj_coef(lp, 0);
             if (temp != 0.0)
                fprintf(fp, "\\* constant term = %.*g *\\\n", DBL_DIG,
                   temp);
