@@ -1,7 +1,7 @@
 /* glpspx1.c (simplex method generic routines) */
 
 /*----------------------------------------------------------------------
--- Copyright (C) 2000, 2001, 2002, 2003, 2004 Andrew Makhorin,
+-- Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 Andrew Makhorin,
 -- Department for Applied Informatics, Moscow Aviation Institute,
 -- Moscow, Russia. All rights reserved. E-mail: <mao@mai2.rcnet.ru>.
 --
@@ -63,10 +63,9 @@ static int inv_col(void *info, int j, int rn[], double bj[])
       SPX *spx = info;
       int m = spx->m;
       int n = spx->n;
-      int *aa_ptr = spx->aa_ptr;
-      int *aa_len = spx->aa_len;
-      int *sv_ndx = spx->aa_ind;
-      double *sv_val = spx->aa_val;
+      int *AT_ptr = spx->AT_ptr;
+      int *AT_ind = spx->AT_ind;
+      double *AT_val = spx->AT_val;
       int *indx = spx->indx;
       int k, ptr, len, t;
       insist(1 <= j && j <= m);
@@ -80,10 +79,10 @@ static int inv_col(void *info, int j, int rn[], double bj[])
       }
       else
       {  /* x[k] is structural variable */
-         ptr = aa_ptr[k];
-         len = aa_len[k];
-         memcpy(&rn[1], &sv_ndx[ptr], len * sizeof(int));
-         memcpy(&bj[1], &sv_val[ptr], len * sizeof(double));
+         ptr = AT_ptr[k-m];
+         len = AT_ptr[k-m+1] - ptr;
+         memcpy(&rn[1], &AT_ind[ptr], len * sizeof(int));
+         memcpy(&bj[1], &AT_val[ptr], len * sizeof(double));
          for (t = len; t >= 1; t--) bj[t] = - bj[t];
       }
       return len;
@@ -304,10 +303,9 @@ double spx_eval_xn_j(SPX *spx, int j)
 void spx_eval_bbar(SPX *spx)
 {     int m = spx->m;
       int n = spx->n;
-      int *aa_ptr = spx->aa_ptr;
-      int *aa_len = spx->aa_len;
-      int *sv_ndx = spx->aa_ind;
-      double *sv_val = spx->aa_val;
+      int *AT_ptr = spx->AT_ptr;
+      int *AT_ind = spx->AT_ind;
+      double *AT_val = spx->AT_val;
       int *indx = spx->indx;
       double *bbar = spx->bbar;
       int i, j, j_beg, j_end, j_ptr, k;
@@ -324,10 +322,9 @@ void spx_eval_bbar(SPX *spx)
          }
          else
          {  /* x[k] is structural variable */
-            j_beg = aa_ptr[k];
-            j_end = j_beg + aa_len[k] - 1;
-            for (j_ptr = j_beg; j_ptr <= j_end; j_ptr++)
-               rhs[sv_ndx[j_ptr]] += sv_val[j_ptr] * xn_j;
+            j_beg = AT_ptr[k-m], j_end = AT_ptr[k-m+1];
+            for (j_ptr = j_beg; j_ptr < j_end; j_ptr++)
+               rhs[AT_ind[j_ptr]] += AT_val[j_ptr] * xn_j;
          }
       }
       /* bbar := inv(B) * rhs */
@@ -403,10 +400,9 @@ void spx_eval_cbar(SPX *spx)
 {     int m = spx->m;
       int n = spx->n;
       double *coef = spx->coef;
-      int *aa_ptr = spx->aa_ptr;
-      int *aa_len = spx->aa_len;
-      int *sv_ndx = spx->aa_ind;
-      double *sv_val = spx->aa_val;
+      int *AT_ptr = spx->AT_ptr;
+      int *AT_ind = spx->AT_ind;
+      double *AT_val = spx->AT_val;
       int *indx = spx->indx;
       double *pi = spx->pi;
       double *cbar = spx->cbar;
@@ -422,10 +418,9 @@ void spx_eval_cbar(SPX *spx)
          }
          else
          {  /* x[k] is structural variable */
-            j_beg = aa_ptr[k];
-            j_end = j_beg + aa_len[k] - 1;
-            for (j_ptr = j_beg; j_ptr <= j_end; j_ptr++)
-               cbar_j += pi[sv_ndx[j_ptr]] * sv_val[j_ptr];
+            j_beg = AT_ptr[k-m], j_end = AT_ptr[k-m+1];
+            for (j_ptr = j_beg; j_ptr < j_end; j_ptr++)
+               cbar_j += pi[AT_ind[j_ptr]] * AT_val[j_ptr];
          }
          cbar[j] = cbar_j;
       }
@@ -500,10 +495,9 @@ double spx_eval_obj(SPX *spx)
 void spx_eval_col(SPX *spx, int j, double col[], int save)
 {     int m = spx->m;
       int n = spx->n;
-      int *aa_ptr = spx->aa_ptr;
-      int *aa_len = spx->aa_len;
-      int *sv_ndx = spx->aa_ind;
-      double *sv_val = spx->aa_val;
+      int *AT_ptr = spx->AT_ptr;
+      int *AT_ind = spx->AT_ind;
+      double *AT_val = spx->AT_val;
       int *indx = spx->indx;
       int i, j_beg, j_end, j_ptr, k;
       double *rhs = col;
@@ -517,10 +511,9 @@ void spx_eval_col(SPX *spx, int j, double col[], int save)
       }
       else
       {  /* x[k] is structural variable */
-         j_beg = aa_ptr[k];
-         j_end = j_beg + aa_len[k] - 1;
-         for (j_ptr = j_beg; j_ptr <= j_end; j_ptr++)
-            rhs[sv_ndx[j_ptr]] = - sv_val[j_ptr];
+         j_beg = AT_ptr[k-m], j_end = AT_ptr[k-m+1];
+         for (j_ptr = j_beg; j_ptr < j_end; j_ptr++)
+            rhs[AT_ind[j_ptr]] = - AT_val[j_ptr];
       }
       /* A^[j] := - inv(B) * N[j] */
       spx_ftran(spx, rhs, save);
@@ -591,10 +584,9 @@ void spx_eval_rho(SPX *spx, int i, double rho[])
 void spx_eval_row(SPX *spx, double rho[], double row[])
 {     int m = spx->m;
       int n = spx->n;
-      int *aa_ptr = spx->aa_ptr;
-      int *aa_len = spx->aa_len;
-      int *sv_ndx = spx->aa_ind;
-      double *sv_val = spx->aa_val;
+      int *A_ptr = spx->A_ptr;
+      int *A_ind = spx->A_ind;
+      double *A_val = spx->A_val;
       int *posx = spx->posx;
       int i, i_beg, i_end, i_ptr, j;
       double rho_i;
@@ -614,13 +606,12 @@ void spx_eval_row(SPX *spx, double rho[], double row[])
          }
          /* look through other non-zero elements in the i-th row of A~
             that correspond to structural variables */
-         i_beg = aa_ptr[i];
-         i_end = i_beg + aa_len[i] - 1;
-         for (i_ptr = i_beg; i_ptr <= i_end; i_ptr++)
-         {  j = posx[sv_ndx[i_ptr] + m] - m;
+         i_beg = A_ptr[i], i_end = A_ptr[i+1];
+         for (i_ptr = i_beg; i_ptr < i_end; i_ptr++)
+         {  j = posx[A_ind[i_ptr] + m] - m;
             if (j > 0)
             {  /* xN[j] is some structural variable */
-               row[j] += rho_i * sv_val[i_ptr];
+               row[j] += rho_i * A_val[i_ptr];
             }
          }
       }
@@ -762,10 +753,9 @@ int spx_prim_chuzc(SPX *spx, double tol)
       int n = spx->n;
       double dir = (spx->dir == LPX_MIN ? +1.0 : -1.0);
       double *coef = spx->coef;
-      int *aa_ptr = spx->aa_ptr;
-      int *aa_len = spx->aa_len;
-      int *sv_ndx = spx->aa_ind;
-      double *sv_val = spx->aa_val;
+      int *AT_ptr = spx->AT_ptr;
+      int *AT_ind = spx->AT_ind;
+      double *AT_val = spx->AT_val;
       int *tagx = spx->tagx;
       int *indx = spx->indx;
       double *pi = spx->pi;
@@ -834,10 +824,9 @@ loop: /* recompute basic solution components (if required) */
             }
             else
             {  /* x[k] is structural variable */
-               j_beg = aa_ptr[k];
-               j_end = j_beg + aa_len[k] - 1;
-               for (j_ptr = j_beg; j_ptr <= j_end; j_ptr++)
-                  cbar_q += pi[sv_ndx[j_ptr]] * sv_val[j_ptr];
+               j_beg = AT_ptr[k-m], j_end = AT_ptr[k-m+1];
+               for (j_ptr = j_beg; j_ptr < j_end; j_ptr++)
+                  cbar_q += pi[AT_ind[j_ptr]] * AT_val[j_ptr];
             }
             /* estimate an error in cbar[q] */
             temp = fabs(cbar[q] - cbar_q) / (1.0 + fabs(cbar_q));
@@ -1773,10 +1762,9 @@ void spx_reset_refsp(SPX *spx)
 void spx_update_gvec(SPX *spx)
 {     int m = spx->m;
       int n = spx->n;
-      int *aa_ptr = spx->aa_ptr;
-      int *aa_len = spx->aa_len;
-      int *sv_ndx = spx->aa_ind;
-      double *sv_val = spx->aa_val;
+      int *AT_ptr = spx->AT_ptr;
+      int *AT_ind = spx->AT_ind;
+      double *AT_val = spx->AT_val;
       int *tagx = spx->tagx;
       int *indx = spx->indx;
       int p = spx->p;
@@ -1842,11 +1830,10 @@ void spx_update_gvec(SPX *spx)
             }
             else
             {  /* x[k] is structural variable */
-               j_beg = aa_ptr[k];
-               j_end = j_beg + aa_len[k] - 1;
                t2 = 0.0;
-               for (j_ptr = j_beg; j_ptr <= j_end; j_ptr++)
-                  t2 -= sv_val[j_ptr] * w[sv_ndx[j_ptr]];
+               j_beg = AT_ptr[k-m], j_end = AT_ptr[k-m+1];
+               for (j_ptr = j_beg; j_ptr < j_end; j_ptr++)
+                  t2 -= AT_val[j_ptr] * w[AT_ind[j_ptr]];
             }
             t3 = ap_j / ap_q;
             s_j += (2.0 * t2 + t1 * t3) * t3;
@@ -1946,10 +1933,9 @@ void spx_update_dvec(SPX *spx)
 {     int m = spx->m;
       int n = spx->n;
       int *typx = spx->typx;
-      int *aa_ptr = spx->aa_ptr;
-      int *aa_len = spx->aa_len;
-      int *sv_ndx = spx->aa_ind;
-      double *sv_val = spx->aa_val;
+      int *AT_ptr = spx->AT_ptr;
+      int *AT_ind = spx->AT_ind;
+      double *AT_val = spx->AT_val;
       int *indx = spx->indx;
       int p = spx->p;
       int q = spx->q;
@@ -1993,10 +1979,9 @@ void spx_update_dvec(SPX *spx)
                w[k] += ap_j;
             else
             {  /* xN[j] is structural variable */
-               j_beg = aa_ptr[k];
-               j_end = j_beg + aa_len[k] - 1;
-               for (j_ptr = j_beg; j_ptr <= j_end; j_ptr++)
-                  w[sv_ndx[j_ptr]] -= ap_j * sv_val[j_ptr];
+               j_beg = AT_ptr[k-m], j_end = AT_ptr[k-m+1];
+               for (j_ptr = j_beg; j_ptr < j_end; j_ptr++)
+                  w[AT_ind[j_ptr]] -= ap_j * AT_val[j_ptr];
             }
          }
       }
